"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileStore = void 0;
/**
 * @author Equinox <ratnesh.pkn@gmail.com>
 * @since 0.1.0
 */
const fs_1 = require("fs");
function isObject(value) {
    const type = typeof value;
    return value != null && (type === "object" || type === "function");
}
function mapObject(value, fn) {
    if (!isObject(value)) {
        return [];
    }
    return Object.keys(value).map((key) => fn(value[key], key));
}
function urlencode(string) {
    return string.replace(/\+/g, "-").replace(/\//g, "_").replace(/=+$/g, "");
}
function getHashCode(key) {
    return urlencode(Buffer.from(key).toString("base64")) + ".json";
}
class FileStore {
    constructor() {
        try {
            fs_1.promises.stat("cache");
        }
        catch (error) {
            const err = error;
            if (err.code === "ENOENT") {
                fs_1.promises.mkdir("cache");
            }
            console.error(error);
        }
    }
    async getItem(key) {
        console.log(key);
        const item = (await fs_1.promises.readFile("cache/" + getHashCode(key))) || null;
        return JSON.parse(item === null || item === void 0 ? void 0 : item.toString());
    }
    async setItem(key, value) {
        console.log(key);
        await fs_1.promises.writeFile("cache/" + getHashCode(key), JSON.stringify(value));
        return value;
    }
    async removeItem(key) {
        console.log(key);
        await fs_1.promises.unlink("cache/" + getHashCode(key));
    }
    async clear() {
        await fs_1.promises.rmdir("cache");
    }
    async length() {
        const files = await fs_1.promises.readdir("cache");
        console.log(files.length);
        return files.length;
    }
    async iterate(fn) {
        const files = await fs_1.promises.readdir("cache");
        const mapOfFiles = files.reduce(async (map, file) => {
            map[file] = await fs_1.promises.readFile(file);
            return map;
        }, {});
        return Promise.all(mapObject(mapOfFiles, fn));
    }
}
exports.FileStore = FileStore;
exports.default = FileStore;
//# sourceMappingURL=index.js.map